# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [0.1.0-alpha.13](https://github.com/lox-space/lox/compare/lox-math-v0.1.0-alpha.12...lox-math-v0.1.0-alpha.13) - 2026-03-02

### Other

- updated the following local packages: lox-core, lox-test-utils

## [0.1.0-alpha.12](https://github.com/lox-space/lox/compare/lox-math-v0.1.0-alpha.11...lox-math-v0.1.0-alpha.12) - 2026-02-27

### Other

- updated the following local packages: lox-core

## [0.1.0-alpha.11](https://github.com/lox-space/lox/compare/lox-math-v0.1.0-alpha.10...lox-math-v0.1.0-alpha.11) - 2026-02-25

### Other

- updated the following local packages: lox-test-utils, lox-core

## [0.1.0-alpha.10](https://github.com/lox-space/lox/compare/lox-math-v0.1.0-alpha.9...lox-math-v0.1.0-alpha.10) - 2026-02-22

### Added

- add optional serde feature

## [0.1.0-alpha.9](https://github.com/lox-space/lox/compare/lox-math-v0.1.0-alpha.8...lox-math-v0.1.0-alpha.9) - 2025-10-29

### Added

- *(lox-earth)* implement new EOP parser and data provider

### Other

- move math code to lox-core
- move lox-units code to lox-core
- update SPDX headers and add helper script
- make Lox REUSE-compliant
- get rid of float_eq and lox_math::is_close
- *(lox-bodies/lox-earth)* anglify lox-bodies and lox-earth
- move type aliases to lox-units
- refactor all the things
- *(lox-units/lox-math)* move constants to lox-units

## [0.1.0-alpha.8](https://github.com/lox-space/lox/compare/lox-math-v0.1.0-alpha.7...lox-math-v0.1.0-alpha.8) - 2025-09-19

### Other

- update Cargo.toml dependencies

## [0.1.0-alpha.7](https://github.com/lox-space/lox/compare/lox-math-v0.1.0-alpha.6...lox-math-v0.1.0-alpha.7) - 2025-07-01

### Other

- fix clippy lints

## [0.1.0-alpha.6](https://github.com/lox-space/lox/compare/lox-math-v0.1.0-alpha.5...lox-math-v0.1.0-alpha.6) - 2025-06-19

### Other

- update Cargo.toml dependencies

## [0.1.0-alpha.5](https://github.com/lox-space/lox/compare/lox-math-v0.1.0-alpha.4...lox-math-v0.1.0-alpha.5) - 2025-03-04

### Other

- update formatting

## [0.1.0-alpha.4](https://github.com/lox-space/lox/compare/lox-math-v0.1.0-alpha.3...lox-math-v0.1.0-alpha.4) - 2025-02-10

### Other

- update Cargo.toml dependencies

## [0.1.0-alpha.3](https://github.com/lox-space/lox/compare/lox-math-v0.1.0-alpha.2...lox-math-v0.1.0-alpha.3) - 2024-12-18

### Other

- fix clippy lints

## [0.1.0-alpha.2](https://github.com/lox-space/lox/compare/lox-math-v0.1.0-alpha.1...lox-math-v0.1.0-alpha.2) - 2024-11-12

### Other

- update Cargo.toml dependencies

## [0.1.0-alpha.1](https://github.com/lox-space/lox/compare/lox-math-v0.1.0-alpha.0...lox-math-v0.1.0-alpha.1) - 2024-07-19

### Other
- release ([#144](https://github.com/lox-space/lox/pull/144))

## [0.1.0-alpha.0](https://github.com/lox-space/lox/releases/tag/lox-math-v0.1.0-alpha.0) - 2024-07-19

### Other
- Rename lox-utils to lox-math because the former is taken ([#146](https://github.com/lox-space/lox/pull/146))
